@@ -1,9 +1,14 @@
+"""
+logic around `PySDM.attributes.impl.derived_attribute.DerivedAttribute` - the parent class
+for all derived attributes
+"""
 from .attribute import Attribute
 
 
 class DerivedAttribute(Attribute):
 
     def __init__(self, builder, name, dependencies):
+        assert len(dependencies) > 0
         super().__init__(builder, name)
         self.dependencies = dependencies
 
