@@ -1,3 +1,6 @@
+"""
+grid cell id attribute
+"""
 from PySDM.attributes.impl.cell_attribute import CellAttribute
 
 
@@ -7,4 +10,4 @@ class CellID(CellAttribute):
         super().__init__(builder, name='cell id', dtype=int)
 
     def recalculate(self):
-        pass
\ No newline at end of file
+        pass
