@@ -1,3 +1,6 @@
+"""
+grid-cell origin (multi-dimensional)
+"""
 from PySDM.attributes.impl.cell_attribute import CellAttribute
 
 
