@@ -1,3 +1,6 @@
+"""
+attributes carrying information on particle physical properties
+"""
 from .multiplicities import Multiplicities
 from .volume import Volume
 from .dry_volume import DryVolume
@@ -7,3 +10,4 @@ from .terminal_velocity import TerminalVelocity
 from .temperature import Temperature
 from .heat import Heat
 from .critical_volume import CriticalVolume
+from .critical_supersaturation import CriticalSupersaturation
