@@ -1,5 +1,7 @@
+"""
+particle dry radius computed from dry volume
+"""
 from PySDM.attributes.impl.derived_attribute import DerivedAttribute
-from PySDM.physics import constants as const
 
 
 class DryRadius(DerivedAttribute):
@@ -9,6 +11,5 @@ class DryRadius(DerivedAttribute):
         super().__init__(builder, name='dry radius', dependencies=dependencies)
 
     def recalculate(self):
-        self.data.idx = self.volume_dry.data.idx
-        self.data.product(self.volume_dry.get(), 1/const.pi_4_3)
+        self.data.product(self.volume_dry.get(), 1 / self.formulae.constants.PI_4_3)
         self.data **= 1/3
