@@ -1,5 +1,7 @@
+"""
+particle wet radius (calculated from the volume)
+"""
 from PySDM.attributes.impl.derived_attribute import DerivedAttribute
-from PySDM.physics import constants as const
 
 
 class Radius(DerivedAttribute):
@@ -10,5 +12,5 @@ class Radius(DerivedAttribute):
 
     def recalculate(self):
         self.data.idx = self.volume.data.idx
-        self.data.product(self.volume.get(), 1/const.pi_4_3)
+        self.data.product(self.volume.get(), 1 / self.formulae.constants.PI_4_3)
         self.data **= 1/3
