@@ -1,12 +1,12 @@
 """
-Backend classes: `CPU`=`PySDM.backends.numba.numba.Numba`
-and `GPU`=`PySDM.backends.thrustRTC.thrustRTC.ThrustRTC`
+Backend classes: CPU=`PySDM.backends.numba.Numba`
+and GPU=`PySDM.backends.thrust_rtc.ThrustRTC`
 """
-from .numba.numba import Numba
 import ctypes
 import warnings
-from numba import cuda
 import sys
+from numba import cuda
+from .numba import Numba
 
 
 # https://gist.github.com/f0k/63a664160d016a491b2cbea15913d549
@@ -26,34 +26,40 @@ def _cuda_is_available():
     if result != 0:  # cuda.h: CUDA_SUCCESS = 0
         error_str = ctypes.c_char_p()
         cuda_lib.cuGetErrorString(result, ctypes.byref(error_str))
+        # pylint: disable=no-member
         warnings.warn(
-            "CUDA library found but cuInit() failed (error code: %d; message: %s)" % (result, error_str.value.decode()))
+            f"CUDA library found but cuInit() failed (error code: {result};"
+            f" message: {error_str.value.decode()})"
+        )
         if 'google.colab' in sys.modules:
-            warnings.warn("to use GPU on Colab set hardware accelerator to 'GPU' before session start"
-                         'in the "Runtime :: Change runtime type :: Hardware accelerator" menu')
+            warnings.warn(
+                "to use GPU on Colab set hardware accelerator to 'GPU' before session start"
+                ' in the "Runtime :: Change runtime type :: Hardware accelerator" menu'
+            )
         return False
 
     return True
 
 
 if _cuda_is_available() or cuda.is_available():
-    from .thrustRTC.thrustRTC import ThrustRTC
+    from PySDM.backends.thrust_rtc import ThrustRTC
 else:
-    from .thrustRTC.test_helpers import _flag
+    from .impl_thrust_rtc.test_helpers import flag
 
-    _flag.fakeThrustRTC = True
+    flag.fakeThrustRTC = True
 
     import numpy as np
 
-    from .thrustRTC.thrustRTC import ThrustRTC
+    from PySDM.backends.thrust_rtc import ThrustRTC  # pylint: disable=ungrouped-imports
     ThrustRTC.ENABLE = False
 
-    class Random:
+    class Random:  # pylint: disable=too-few-public-methods
         def __init__(self, size, seed):
             self.size = size
             self.generator = np.random.default_rng(seed)
 
         def __call__(self, storage):
+            # pylint: disable=unsupported-assignment-operation
             storage.data.ndarray[:] = self.generator.uniform(0, 1, storage.shape)
 
     ThrustRTC.Random = Random
