@@ -1,3 +1,6 @@
+"""
+clever reuser of random numbers for use in adaptive coalescence
+"""
 import math
 
 
@@ -16,8 +19,10 @@ class RandomGeneratorOptimizer:
     def register(self, builder):
         self.particulator = builder.particulator
         shift = math.ceil(self.particulator.dt / self.dt_min) if self.optimized_random else 0
-        self.pairs_rand = self.particulator.Storage.empty(self.particulator.n_sd + shift, dtype=float)
-        self.rand = self.particulator.Storage.empty(self.particulator.n_sd // 2, dtype=float)
+        self.pairs_rand = self.particulator.Storage.empty(
+            self.particulator.n_sd + shift, dtype=float)
+        self.rand = self.particulator.Storage.empty(
+            self.particulator.n_sd // 2, dtype=float)
         self.rnd = self.particulator.Random(self.particulator.n_sd + shift, self.seed)
 
     def reset(self):
