@@ -1,9 +1,8 @@
 """
 Bare zero-dimensional framework
 """
-
-from PySDM.state.mesh import Mesh
 import numpy as np
+from PySDM.impl.mesh import Mesh
 
 
 class Box:
@@ -18,12 +17,17 @@ class Box:
         return self._ambient_air[item]
 
     def __setitem__(self, key, value):
-        self._ambient_air[key] = self.particulator.backend.Storage.from_ndarray(np.array([value]))
+        if key not in self._ambient_air:
+            self._ambient_air[key] = self.particulator.backend.Storage.from_ndarray(
+                np.array([value]))
+        else:
+            self._ambient_air[key][:] = value
 
     def register(self, builder):
         self.particulator = builder.particulator
 
     def init_attributes(self, *, spectral_discretisation):
         attributes = {}
-        attributes['volume'], attributes['n'] = spectral_discretisation.sample(self.particulator.n_sd)
+        attributes['volume'], attributes['n'] = spectral_discretisation.sample(
+            self.particulator.n_sd)
         return attributes
