@@ -3,18 +3,18 @@ Single-column time-varying-updraft framework with moisture advection handled by
 [PyMPDATA](http://github.com/atmos-cloud-sim-uj/PyMPDATA/)
 """
 
-from ._moist import _Moist
-from ..initialisation.r_wet_init import r_wet_init
-from ..initialisation.multiplicities import discretise_n
-from ..state import arakawa_c
 import numpy as np
+from PySDM.environments.impl.moist import Moist
+from ..initialisation.equilibrate_wet_radii import equilibrate_wet_radii
+from ..impl import arakawa_c
 
 
-class Kinematic1D(_Moist):
+class Kinematic1D(Moist):
     def __init__(self, dt, mesh, thd_of_z, rhod_of_z):
         super().__init__(dt, mesh, [])
         self.thd0 = thd_of_z(mesh.dz * arakawa_c.z_scalar_coord(mesh.grid))
         self.rhod = rhod_of_z(mesh.dz * arakawa_c.z_scalar_coord(mesh.grid))
+        self.formulae = None
 
     def register(self, builder):
         super().register(builder)
@@ -46,21 +46,20 @@ class Kinematic1D(_Moist):
             r_dry, n_per_kg = spectral_discretisation.sample(self.particulator.n_sd)
             attributes['dry volume'] = self.formulae.trivia.volume(radius=r_dry)
             attributes['kappa times dry volume'] = attributes['dry volume'] * kappa
-            r_wet = r_wet_init(r_dry, self, cell_id=attributes['cell id'],
-                               kappa_times_dry_volume=attributes['kappa times dry volume'])
+            r_wet = equilibrate_wet_radii(
+                r_dry, self, cell_id=attributes['cell id'],
+                kappa_times_dry_volume=attributes['kappa times dry volume']
+            )
 
             rhod = self['rhod'].to_ndarray()
             cell_id = attributes['cell id']
             domain_volume = np.prod(np.array(self.mesh.size))
 
-        attributes['n'] = discretise_n(n_per_kg * rhod[cell_id] * domain_volume)
+        attributes['n'] = n_per_kg * rhod[cell_id] * domain_volume
         attributes['volume'] = self.formulae.trivia.volume(radius=r_wet)
 
         return attributes
 
-    def sync(self):
-        super().sync()
-
     @property
     def dv(self):
         return self.mesh.dv
