@@ -1,5 +1,5 @@
 """
-Exporters module
+Exporters handling output to metadata-rich file formats incl. netCDF and VTK
 """
 from .vtk_exporter import VTKExporter
 from .netcdf_exporter import NetCDFExporter
