@@ -1,5 +1,6 @@
 """
 Formulae for representing the temperature and pressure dependence of vapour diffusion coefficient
 """
-from .negclect import Neglect
+from .neglect import Neglect
 from .tracy_welch_porter import TracyWelchPorter
+from . lowe_et_al_2019 import LoweEtAl2019
