@@ -1,9 +1,14 @@
-import PySDM.physics.constants as const
+"""
+single-equation approximation of the vapour and heat diffusion problem
+"""
 
 
 class MaxwellMason:
+    def __init__(self, _):
+        pass
+
     @staticmethod
-    def r_dr_dt(RH_eq, T, RH, lv, pvs, D, K):
+    def r_dr_dt(const, RH_eq, T, RH, lv, pvs, D, K):
         return (RH - RH_eq) / (
                 const.rho_w * const.Rv * T / D / pvs +
                 const.rho_w * lv / K / T * (lv / const.Rv / T - 1)
