@@ -1,5 +1,7 @@
 """
 Alternative formulations of saturation vapour pressure temperature dependence approximations
 """
+from .flatau_walko_cotton import FlatauWalkoCotton
 from .august_roche_magnus import AugustRocheMagnus
-from .flatau_walko_cotton import FlatauWalkoCotton
\ No newline at end of file
+from .lowe1977 import Lowe1977
+from .murphy_koop_2005 import MurphyKoop2005
