@@ -1,10 +1,11 @@
-from PySDM.backends.numba.toms748 import toms748_solve
-from scipy.optimize.zeros import toms748
-from PySDM.physics.formulae import Formulae
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
+import os
 import numba
 import numpy as np
-import os
 import pytest
+from scipy.optimize.zeros import toms748
+from PySDM.backends.impl_numba.toms748 import toms748_solve
+from PySDM.formulae import Formulae
 
 # relevant
 # https://github.com/scipy/scipy/blob/master/scipy/optimize/tests/test_zeros.py
@@ -29,7 +30,11 @@ def test_toms748(fun):
     b = .5
     rtol = 1e-6
     wt = Formulae().trivia.within_tolerance
-    actual, iters = sut(f2, (), ax=a, bx=b, fax=f2(a), fbx=f2(b), max_iter=10, rtol=rtol, within_tolerance=wt)
-    expected = toms748(f2, a, b)
+    actual, _ = sut(
+        fun, (),
+        ax=a, bx=b,
+        fax=fun(a), fbx=fun(b),
+        max_iter=10, rtol=rtol, within_tolerance=wt)
+    expected = toms748(fun, a, b)
 
     np.testing.assert_almost_equal(actual, expected)
