@@ -1,14 +1,16 @@
-from PySDM.state.mesh import Mesh
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
 import numpy as np
+from PySDM.impl.mesh import Mesh
 
 
 class DummyEnvironment:
 
-    def __init__(self, dt=None, grid=None, size=None, dv=None, courant_field_data=None, halo=None):
+    def __init__(self, timestep=None, grid=None, size=None, volume=None,
+                 courant_field_data=None, halo=None):
         self.particulator = None
-        self.dt = dt
+        self.dt = timestep
         if grid is None:
-            self.mesh = Mesh.mesh_0d(dv)
+            self.mesh = Mesh.mesh_0d(volume)
         else:
             if size is None:
                 size = tuple(1 for _ in range(len(grid)))
@@ -24,8 +26,8 @@ class DummyEnvironment:
     def register(self, particulator):
         self.particulator = particulator
         if hasattr(self, 'halo'):
-            self.pred['qv'] = particulator.bck.Storage.empty(self.mesh.n_cell, dtype=float)
-            self.pred['thd'] = particulator.bck.Storage.empty(self.mesh.n_cell, dtype=float)
+            self.pred['qv'] = particulator.backend.Storage.empty(self.mesh.n_cell, dtype=float)
+            self.pred['thd'] = particulator.backend.Storage.empty(self.mesh.n_cell, dtype=float)
 
     def get_courant_field_data(self):
         return self.courant_field_data
@@ -34,10 +36,16 @@ class DummyEnvironment:
         return self.pred[key]
 
     def get_qv(self):
-        return self.qv[self.halo:-self.halo, self.halo:-self.halo]
+        if self.halo is not None:
+            halo = int(self.halo)
+            return self.qv[halo:-halo, halo:-halo]
+        raise ValueError()
 
     def get_thd(self):
-        return self.thd[self.halo:-self.halo, self.halo:-self.halo]
+        if self.halo is not None:
+            halo = int(self.halo)
+            return self.thd[halo:-halo, halo:-halo]
+        raise ValueError()
 
     def sync(self):
         pass
