@@ -1,11 +1,12 @@
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
 #from ....backends_fixture import backend # TODO #588
-from PySDM.backends import CPU
-from PySDM import Builder
-from PySDM.state.mesh import Mesh
-from PySDM.dynamics.condensation import Condensation
-import numpy as np
 import re
 import fnmatch
+import numpy as np
+from PySDM.backends import CPU
+from PySDM import Builder
+from PySDM.impl.mesh import Mesh
+from PySDM.dynamics.condensation import Condensation
 
 
 class _TestEnv:
@@ -19,7 +20,8 @@ class _TestEnv:
 
     def register(self, builder):
         self.particulator = builder.particulator
-        self.full = lambda item: self.particulator.backend.Storage.from_ndarray(np.full(self.particulator.n_sd, self.env[item]))
+        self.full = lambda item: self.particulator.backend.Storage.from_ndarray(
+            np.full(self.particulator.n_sd, self.env[item]))
 
     def get_predicted(self, item):
         return self.full(item)
@@ -30,10 +32,16 @@ class _TestEnv:
 
 class _TestParticulator:
     def __init__(self, backend, n_sd=-1, max_iters=-1, multiplicity=-1,
-                 dt=np.nan, dv=np.nan, rhod=np.nan, thd=np.nan, qv=np.nan, T=np.nan, p=np.nan, RH=np.nan,
+                 dt=np.nan, dv=np.nan,
+                 rhod=np.nan, thd=np.nan, qv=np.nan,
+                 T=np.nan, p=np.nan, RH=np.nan,
                  dry_volume=np.nan, wet_radius=np.nan):
         builder = Builder(n_sd=n_sd, backend=backend())
-        builder.set_environment(_TestEnv(dt=dt, dv=dv, rhod=rhod, thd=thd, qv=qv, T=T, p=p, RH=RH))
+        builder.set_environment(_TestEnv(
+            dt=dt, dv=dv,
+            rhod=rhod, thd=thd, qv=qv,
+            T=T, p=p, RH=RH
+        ))
         builder.add_dynamic(Condensation(max_iters=max_iters))
         self.particulator = builder.build(attributes={
             'n': np.full(n_sd, multiplicity),
@@ -50,8 +58,8 @@ def _try(particulator, capsys):
     exception = None
     try:
         particulator.run(steps=1)
-    except Exception as e:
-       exception = e
+    except Exception as e:  # pylint: disable=broad-except
+        exception = e
     captured = capsys.readouterr()
     assert captured.out == ""
     assert isinstance(exception, RuntimeError)
@@ -66,12 +74,16 @@ class TestDiagnostics:
     @staticmethod
     def test_burnout_long(capsys, backend=CPU):
         # arrange
-        particulator = _TestParticulator(backend, dt=1, T=1, qv=1, dv=1, rhod=1, thd=1., max_iters=1, n_sd=1,
-                                 multiplicity=1, dry_volume=1, wet_radius=1)
+        particulator = _TestParticulator(
+            backend, dt=1, T=1, qv=1, dv=1, rhod=1, thd=1., max_iters=1, n_sd=1,
+            multiplicity=1, dry_volume=1, wet_radius=1
+        )
 
         # act
-        exception, captured_err = _try(particulator, capsys)
+        _, captured_err = _try(particulator, capsys)
 
         # assert
-        pattern = re.compile(r"^burnout \(long\)\n\tfile: " + FN + r"\n\tcontext:\n\t\t thd\n\t\t 1.0\n$")
+        pattern = re.compile(
+            r"^burnout \(long\)\n\tfile: " + FN + r"\n\tcontext:\n\t\t thd\n\t\t 1.0\n$"
+        )
         assert pattern.match(captured_err) is not None
