@@ -1,17 +1,20 @@
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
+import numpy as np
 from PySDM.dynamics import EulerianAdvection
 from ..dummy_particulator import DummyParticulator
 from ..dummy_environment import DummyEnvironment
-import numpy as np
-# noinspection PyUnresolvedReferences
-from ...backends_fixture import backend
+from ...backends_fixture import backend_class
+
+assert hasattr(backend_class, '_pytestfixturefunction')
 
 
 class TestEulerianAdvection:
 
     @staticmethod
-    def test_update(backend):
+    # pylint: disable=redefined-outer-name
+    def test_update(backend_class):
         # Arrange
-        particulator = DummyParticulator(backend)
+        particulator = DummyParticulator(backend_class)
         halo = 3
         grid = (11, 13)
         env = DummyEnvironment(grid=grid, halo=halo)
@@ -29,5 +32,9 @@ class TestEulerianAdvection:
         sut()
 
         # Assert
-        np.testing.assert_array_equal(env.get_qv(), env.get_predicted('qv').to_ndarray().reshape(grid))
-        np.testing.assert_array_equal(env.get_thd(), env.get_predicted('thd').to_ndarray().reshape(grid))
+        np.testing.assert_array_equal(
+            env.get_qv(),
+            env.get_predicted('qv').to_ndarray().reshape(grid))
+        np.testing.assert_array_equal(
+            env.get_thd(),
+            env.get_predicted('thd').to_ndarray().reshape(grid))
