@@ -1,7 +1,7 @@
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
 import importlib
 import os
 import numpy as np
-import pytest
 from PySDM.physics import constants
 
 
@@ -10,9 +10,9 @@ def consecutive_seeds():
     for _ in range(5):
         importlib.reload(constants)
         seeds.append(constants.default_random_seed)
-    print(seeds)
     return np.asarray(seeds)
 
+
 class TestConstants:
     @staticmethod
     def test_constant_seed_on_CI():
