@@ -1,12 +1,15 @@
+# pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
 from .dummy_particulator import DummyParticulator
-# noinspection PyUnresolvedReferences
-from ..backends_fixture import backend
+from ..backends_fixture import backend_class
+
+assert hasattr(backend_class, '_pytestfixturefunction')
 
 
 class TestParticulator:
 
     @staticmethod
-    def test_observer(backend):
+    # pylint: disable=redefined-outer-name
+    def test_observer(backend_class):
         class Observer:
             def __init__(self, particulator):
                 self.steps = 0
@@ -18,7 +21,7 @@ class TestParticulator:
                 assert self.steps == self.particulator.n_steps
 
         steps = 33
-        particulator = DummyParticulator(backend, 44)
+        particulator = DummyParticulator(backend_class, 44)
         observer = Observer(particulator)
         particulator.run(steps)
 
